@@ -1,19 +1,19 @@
+"""utility functions to fetch variables and secrets"""
+
 import copy
 import enum
 import getpass
 import os
 import stat
-import string
 import sys
 import typing
 import warnings
-from urllib.parse import urljoin
 
 import crontab
 import pydantic
-import requests
 import yaml
-from deeporigin import auth
+from deeporigin.platform.api import get_variables_and_secrets
+from deeporigin.utils.core import _get_api_tokens_filepath
 
 from ..config import get_value as get_config
 from ..exceptions import DeepOriginException
@@ -78,7 +78,7 @@ def get_variable_types_by_values(values: list[str]) -> list[VariableType]:
                 ),
             ]
         )
-        raise DeepOriginException(msg)
+        raise DeepOriginException(message=msg)
 
     return types
 
@@ -91,9 +91,9 @@ def install_variables(
     overwrite: bool = False,
 ) -> dict[str, dict[str, typing.Union[str, VariableType]]]:
     """
-    Retrieve the variables and secrets for your bench from the Deep Origin platform and
-    install them into the bench. Includes your variables and secrets, as well as those of
-    the parent organization of the bench.
+    Retrieve the variables and secrets for your workstation from the Deep Origin OS and
+    install them into the workstation. Includes your variables and secrets, as well as those of
+    the parent organization of the workstation.
 
     Args:
         user (:obj:`bool`, optional): Whether to retrieve and install user variables and secrets
@@ -107,7 +107,7 @@ def install_variables(
     """
     prev_variables = get_variables_from_local()
 
-    # get variables from the DO platform
+    # get variables from the DO OS
     variables = get_variables_from_do_platform(user=user, org=org, types=types)
 
     # determine which variables were added, modified, removed, or unmodified
@@ -189,9 +189,9 @@ def get_variables_from_do_platform(
     types: typing.Iterable[VariableType] = tuple(VariableType.__members__.values()),
 ) -> list[Variable]:
     """
-    Retrieve the variables and secrets for your bench from the Deep Origin platform.
+    Retrieve the variables and secrets for your workstation from the Deep Origin OS.
     Includes your variables and secrets, as well as those of the parent organization
-    of the bench.
+    of the workstation.
 
     Args:
         user (:obj:`bool`, optional): Whether to retrieve and install user variables and secrets
@@ -207,39 +207,28 @@ def get_variables_from_do_platform(
         return []
 
     classes = tuple([type.value for type in types])
-    config = get_config()
 
-    # Get an access token for the Deep Origin API
-    tokens = auth.get_tokens()
+    secrets = get_variables_and_secrets()
 
-    # Query variables API endpoint.
-    #
-    # TODO Support filtering for
-    # - Just user's variables
-    # - Just organization variables
-    bench_drn = f"drn:compute:{config.organization_id}:computebench:{config.bench_id}"
-    query = string.Template(config.list_bench_variables_query_template).substitute(
-        bench_drn=bench_drn
-    )
-
-    response = requests.post(
-        urljoin(config.api_endpoint, config.graphql_api_route),
-        json={
-            "query": query,
-        },
-        headers={
-            "Authorization": f"Bearer {tokens['access']}",
-        },
-    )
-    response.raise_for_status()
-    response_json = response.json()
+    # reshape secrets to match what we had in the old
+    # graph QL response
+    reshaped_secrets = []
+    keys = ["key", "filename"]
+    for secret in secrets:
+        data = dict()
+        data["name"] = secret["attributes"]["name"]
+        data["type"] = secret["attributes"]["type"]
+        for key in keys:
+            if key in secret["attributes"].keys():
+                data[key] = secret["attributes"][key]
+        data["value"] = secret["attributes"]["value"]
+        data["drn"] = "drn:variable:" + secret["id"]
+        reshaped_secrets.append(data)
 
     # Parse GraphQL response
     variables = []
     invalid_variables = []
-    for serialized_variable in response_json.get("data", {}).get(
-        "listBenchSecrets", []
-    ):
+    for serialized_variable in reshaped_secrets:
         try:
             variable = deserialize_variable(serialized_variable)
 
@@ -257,7 +246,7 @@ def get_variables_from_do_platform(
         msg = f"{len(invalid_variables)} variables are not valid.\n\n" + "\n\n".join(
             invalid_variables
         )
-        raise DeepOriginException(msg)
+        raise DeepOriginException(message=msg)
 
     # return variables
     return variables
@@ -272,13 +261,17 @@ def deserialize_variable(serialized: dict) -> Variable:
     Returns:
         :obj:`Variable`: variable
     """
+    serialized = serialized.copy()
+
     type_platform_id = serialized.pop("type")
 
     for cls in VariableType.__members__.values():
         if cls.value.Meta.platform_id == type_platform_id:
             return cls.value.from_platform(serialized)
 
-    raise DeepOriginException(f"{type} is not a valid type of variable or secret.")
+    raise DeepOriginException(
+        message=f"{type} is not a valid type of variable or secret."
+    )
 
 
 def is_variable_modified(variable: Variable) -> bool:
@@ -359,15 +352,15 @@ def enable_variable_auto_updating(
     cli: typing.Optional[str] = None,
 ) -> None:
     """
-    Configure the variables and secrets for your bench from the Deep Origin
-    platform to be automatically installed once added or modified. Includes your
-    variables and secrets, as well as those of the parent organization of the bench.
+    Configure the variables and secrets for your workstation from the Deep Origin
+    OS to be automatically installed once added or modified. Includes your
+    variables and secrets, as well as those of the parent organization of the workstation.
 
     Args:
         user (:obj:`bool`, optional): Whether to retrieve and install user variables and secrets
         org (:obj:`bool`, optional): Whether to retrieve and install organization variables and secrets
         types (:obj:`typing.Iterable`, optional): Types of variables and secrets to retrieve and install
-        time_period_min (:obj:`int`, optional): Time period for updating variables from the Deep Origin platform [default: 30, units: min]
+        time_period_min (:obj:`int`, optional): Time period for updating variables from the Deep Origin OS [default: 30, units: min]
         overwrite (:obj:`bool`, optional): Whether to overwrite direct changes to variables and secrets
     """
     # login
@@ -390,7 +383,7 @@ def enable_variable_auto_updating(
         # assemble the command for the job
         config = get_config()
         escaped_organization_id = config.organization_id.replace("'", "\\'")
-        escaped_bench_id = config.bench_id.replace("'", "\\'")
+        escaped_workstation_id = config.bench_id.replace("'", "\\'")
         escaped_env = config.env.replace("'", "\\'")
         escaped_api_endpoint = config.api_endpoint.replace("'", "\\'")
         escaped_auth_domain = config.auth_domain.replace("'", "\\'")
@@ -402,12 +395,10 @@ def enable_variable_auto_updating(
         escaped_auth_grant_type = config.auth_grant_type.replace("'", "\\'")
         escaped_auth_client_id = config.auth_client_id.replace("'", "\\'")
         escaped_auth_client_secret = config.auth_client_secret.replace("'", "\\'")
-        escaped_list_bench_variables_query_template = (
-            config.list_bench_variables_query_template.replace("\n", " ").replace(
-                "'", "\\'"
-            )
+
+        escaped_api_tokens_filename = str(_get_api_tokens_filepath()).replace(
+            "'", "\\'"
         )
-        escaped_api_tokens_filename = config.api_tokens_filename.replace("'", "\\'")
         escaped_variables_cache_filename = config.variables_cache_filename.replace(
             "'", "\\'"
         )
@@ -425,7 +416,7 @@ def enable_variable_auto_updating(
         commands.append(
             f"export DEEP_ORIGIN_ORGANIZATION_ID='{escaped_organization_id}'"
         )
-        commands.append(f"export DEEP_ORIGIN_BENCH_ID='{escaped_bench_id}'")
+        commands.append(f"export DEEP_ORIGIN_BENCH_ID='{escaped_workstation_id}'")
         commands.append(f"export DEEP_ORIGIN_ENV='{escaped_env}'")
         commands.append(f"export DEEP_ORIGIN_API_ENDPOINT='{escaped_api_endpoint}'")
         commands.append(f"export DEEP_ORIGIN_AUTH_DOMAIN='{escaped_auth_domain}'")
@@ -443,9 +434,6 @@ def enable_variable_auto_updating(
         commands.append(
             f"export DEEP_ORIGIN_AUTH_CLIENT_SECRET='{escaped_auth_client_secret}'"
         )
-        commands.append(
-            f"export DEEP_ORIGIN_LIST_BENCH_VARIABLES_QUERY_TEMPLATE='{escaped_list_bench_variables_query_template}'"
-        )
 
         commands.append(
             f"export DEEP_ORIGIN_API_TOKENS_FILENAME='{escaped_api_tokens_filename}'"
@@ -463,7 +451,7 @@ def enable_variable_auto_updating(
                 "pytest/__main__.py"
             ):
                 raise DeepOriginException(
-                    "Auto installation must be run from the Deep Origin CLI"
+                    message="Auto installation must be run from the Deep Origin CLI"
                 )
 
         cli_command = [cli, "variables", "install"]
@@ -510,10 +498,6 @@ def disable_variable_auto_updating() -> None:
         for job in cron_tab.find_comment(comment=cron_job_id):
             job.enable(False)
 
-    config = get_config()
-    if os.path.isfile(config.api_tokens_filename):
-        auth.remove_cached_tokens()
-
 
 def get_auto_install_variables_cronjob_id() -> str:
     """Get the id for the cron job for auto updating Deep Origin variables
@@ -532,7 +516,7 @@ def uninstall_variables(
     overwrite: bool = False,
 ) -> None:
     """
-    Remove variables and secrets retrieved from the Deep Origin platform, including
+    Remove variables and secrets retrieved from the Deep Origin OS, including
     uninstalling variables and secrets.
 
     Args:
